@@ -1,11 +1,12 @@
-context("f7Accordion")
+library(shinytest2)
 
 test_that("accordion", {
   expect_true(inherits(f7Accordion(), "shiny.tag"))
-  expect_equal(
-    f7Accordion()$attribs$class,
-    "list accordion-list"
-  )
+  expect_equal(f7Accordion()$attribs$class, "list list-strong list-outline-ios list-dividers-ios inset-md accordion-list")
+
+  # Opposite
+  cl <- f7Accordion(side = "left")$attribs$class
+  expect_true(grepl("accordion-opposite", cl))
 
   # id
   expect_equal(
@@ -15,15 +16,8 @@ test_that("accordion", {
 
   # check that children are wrapped by an <ul></ul>
   expect_equal(f7Accordion()$children[[1]]$name, "ul")
-
-  # multicollapse
-  expect_equal(
-    f7Accordion(multiCollapse = TRUE)$attribs$class,
-    "list"
-  )
 })
 
-
 test_that("accordion items", {
   expect_true(inherits(f7AccordionItem(), "shiny.tag"))
   expect_equal(f7AccordionItem()$name, "li")
@@ -43,13 +37,11 @@ test_that("accordion items", {
   expect_equal(item[[2]]$attribs$class, "accordion-item-content")
 })
 
-
 test_that("update", {
-
   session <- as.environment(list(
     ns = identity,
     sendInputMessage = function(inputId, message) {
-      session$lastInputMessage = list(id = inputId, message = message)
+      session$lastInputMessage <- list(id = inputId, message = message)
     }
   ))
 
@@ -58,5 +50,20 @@ test_that("update", {
 
   expect_equal(result$message$selected, 1)
   expect_equal(result$id, "accordion")
+})
 
+test_that("accordion works as expected", {
+  # Don't run these tests on the CRAN build servers
+  skip_on_cran()
+  shiny_app_path <-
+    system.file("examples/accordion/app.R", package = "shinyMobile")
+  app <- AppDriver$new(
+    shiny_app_path,
+    name = "accordion-app"
+  )
+  app$expect_values(input = "myaccordion1")
+  app$click(selector = "#go")
+  # Animation/transition takes a bit of time
+  app$wait_for_idle(1000)
+  app$expect_values(input = "myaccordion1")
 })
