@@ -1,4 +1,19 @@
-context("f7Button")
+library(shinytest2)
+
+test_that("button works as expected", {
+  # Don't run these tests on the CRAN build servers
+  skip_on_cran()
+  shiny_app_path <-
+    system.file("examples/button/app.R", package = "shinyMobile")
+  app <- AppDriver$new(
+    shiny_app_path,
+    name = "button-app"
+  )
+  app$expect_values(input = "button")
+  app$click(selector = "#update")
+  app$wait_for_idle(1000)
+  app$expect_values(input = "button")
+})
 
 test_that("button", {
   expect_true(inherits(f7Button(), "shiny.tag"))
@@ -21,43 +36,28 @@ test_that("button", {
   expect_equal(f7Button(color = "pink")$attribs$class, "button color-pink button-fill")
   expect_equal(f7Button(active = TRUE)$attribs$class, "button button-fill button-active")
 
+  expect_equal(f7Button(tonal = TRUE)$attribs$class, "button button-fill button-tonal")
   # input binding class
   expect_equal(f7Button(inputId = "test")$attribs$class, "button f7-action-button button-fill")
 })
 
-
-context("f7Segment")
-
 test_that("f7Segment", {
-  expect_true(inherits(f7Segment(container = "segment"), "shiny.tag"))
-
-  # error
-  expect_error(f7Segment(container = "row", rounded = TRUE))
-  expect_error(f7Segment(container = "row", shadow = TRUE))
+  expect_true(inherits(f7Segment(), "shiny.tag"))
 
   # class
-  expect_equal(f7Segment(container = "segment")$attribs$class, "block")
-  expect_equal(f7Segment(container = "segment")$children[[1]]$attribs$class, "segmented")
-  expect_equal(f7Segment(container = "row")$children[[1]]$attribs$class, "row")
+  expect_equal(f7Segment()$attribs$class, "block")
+  expect_equal(f7Segment()$children[[1]]$attribs$class, "segmented")
   expect_equal(
-    f7Segment(container = "segment", shadow = TRUE)$children[[1]]$attribs$class,
+    f7Segment(shadow = TRUE)$children[[1]]$attribs$class,
     "segmented segmented-raised"
   )
   expect_equal(
-    f7Segment(container = "segment", rounded = TRUE)$children[[1]]$attribs$class,
+    f7Segment(rounded = TRUE)$children[[1]]$attribs$class,
     "segmented segmented-round"
   )
 
   expect_equal(
-    f7Segment(container = "segment", strong = TRUE)$children[[1]]$attribs$class,
+    f7Segment(strong = TRUE)$children[[1]]$attribs$class,
     "segmented segmented-strong"
   )
-
-  # structure: check children elements inside
-  #segmentTag <- f7Segment(container = "row", lapply(1:3, f7Button))
-  #expect_length(segmentTag$children[[1]]$children[[1]][[1]], 4)
-  #bttn1 <- segmentTag$children[[1]]$children[[1]][[1]][[1]]
-  #expect_match(bttn1[[2]]$attribs$class, "col")
-
-
 })
